==> risk-center-api-0.4.14-20181129.022744-20-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/AdvertSecondReviewDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

// 广告计划复审列表dto
@ApiModel
public class AdvertSecondReviewDto implements Serializable {
	@ApiModelProperty("广告id")
	private Long advertId;
	@ApiModelProperty("广告名称")
	private String advertName;
	@ApiModelProperty("广告主名称")
	private String advertMaster;
	@ApiModelProperty("代理商名称")
	private String agentName;
	@ApiModelProperty("来源")
	private Integer source;
	@ApiModelProperty("审核状态 0 待复审   1，2 已复审")
	private Integer reviewStatus;  // 0 待复审   1，2 已复审
	@ApiModelProperty("初审结果 1 初审通过 2 初审拒绝")
	private Integer firstResult;
	@ApiModelProperty("复审结果 0 待复审 1 复审通过 2 复审拒绝")
	private Integer secondResult;
	@ApiModelProperty("初审备注")
	private String firstMemo;
	@ApiModelProperty("复审备注")
	private String secondMemo;
	@ApiModelProperty("最近审核时间")
	private Date lastReviewTime;
	@ApiModelProperty("初审")
	private String firstReviewer;
	@ApiModelProperty("ae")
	private String ae;
	@ApiModelProperty("销售")
	private String sale;
	@ApiModelProperty("复审")
	private String secondReviewer;
	@ApiModelProperty("标签")
	private List<RpsTagsDto> labels;

	public Long getAdvertId() {
		return advertId;
	}

	public void setAdvertId(Long advertId) {
		this.advertId = advertId;
	}

	public String getAdvertName() {
		return advertName;
	}

	public void setAdvertName(String advertName) {
		this.advertName = advertName;
	}

	public String getAdvertMaster() {
		return advertMaster;
	}

	public void setAdvertMaster(String advertMaster) {
		this.advertMaster = advertMaster;
	}

	public String getAgentName() {
		return agentName;
	}

	public void setAgentName(String agentName) {
		this.agentName = agentName;
	}

	public Integer getSource() {
		return source;
	}

	public void setSource(Integer source) {
		this.source = source;
	}

	public Integer getReviewStatus() {
		return reviewStatus;
	}

	public void setReviewStatus(Integer reviewStatus) {
		this.reviewStatus = reviewStatus;
	}

	public Integer getFirstResult() {
		return firstResult;
	}

	public void setFirstResult(Integer firstResult) {
		this.firstResult = firstResult;
	}

	public Integer getSecondResult() {
		return secondResult;
	}

	public void setSecondResult(Integer secondResult) {
		this.secondResult = secondResult;
	}

	public String getFirstMemo() {
		return firstMemo;
	}

	public void setFirstMemo(String firstMemo) {
		this.firstMemo = firstMemo;
	}

	public String getSecondMemo() {
		return secondMemo;
	}

	public void setSecondMemo(String secondMemo) {
		this.secondMemo = secondMemo;
	}

	public Date getLastReviewTime() {
		return lastReviewTime;
	}

	public void setLastReviewTime(Date lastReviewTime) {
		this.lastReviewTime = lastReviewTime;
	}

	public String getFirstReviewer() {
		return firstReviewer;
	}

	public void setFirstReviewer(String firstReviewer) {
		this.firstReviewer = firstReviewer;
	}

	public String getAe() {
		return ae;
	}

	public void setAe(String ae) {
		this.ae = ae;
	}

	public String getSale() {
		return sale;
	}

	public void setSale(String sale) {
		this.sale = sale;
	}

	public String getSecondReviewer() {
		return secondReviewer;
	}

	public void setSecondReviewer(String secondReviewer) {
		this.secondReviewer = secondReviewer;
	}

	public List<RpsTagsDto> getLabels() {
		return labels;
	}

	public void setLabels(List<RpsTagsDto> labels) {
		this.labels = labels;
	}
}

==> risk-center-api-0.4.33-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/AdvertSecondReviewDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

// 广告计划复审列表dto
@ApiModel
public class AdvertSecondReviewDto implements Serializable {
	@ApiModelProperty("广告id")
	private Long advertId;
	@ApiModelProperty("广告名称")
	private String advertName;
	@ApiModelProperty("广告主名称")
	private String advertMaster;
	@ApiModelProperty("代理商名称")
	private String agentName;
	@ApiModelProperty("来源")
	private Integer source;
	@ApiModelProperty("审核状态 0 待复审   1，2 已复审")
	private Integer reviewStatus;  // 0 待复审   1，2 已复审
	@ApiModelProperty("初审结果 1 初审通过 2 初审拒绝")
	private Integer firstResult;
	@ApiModelProperty("复审结果 0 待复审 1 复审通过 2 复审拒绝")
	private Integer secondResult;
	@ApiModelProperty("初审备注")
	private String firstMemo;
	@ApiModelProperty("复审备注")
	private String secondMemo;
	@ApiModelProperty("最近审核时间")
	private Date lastReviewTime;
	@ApiModelProperty("初审")
	private String firstReviewer;
	@ApiModelProperty("ae")
	private String ae;
	@ApiModelProperty("销售")
	private String sale;
	@ApiModelProperty("复审")
	private String secondReviewer;
	@ApiModelProperty("标签")
	private List<RpsTagsDto> labels;
	@ApiModelProperty("广告类型,1-互动广告、2-展示广告、3-激励广告")
	private Integer advertType;

	public Long getAdvertId() {
		return advertId;
	}

	public void setAdvertId(Long advertId) {
		this.advertId = advertId;
	}

	public String getAdvertName() {
		return advertName;
	}

	public void setAdvertName(String advertName) {
		this.advertName = advertName;
	}

	public String getAdvertMaster() {
		return advertMaster;
	}

	public void setAdvertMaster(String advertMaster) {
		this.advertMaster = advertMaster;
	}

	public String getAgentName() {
		return agentName;
	}

	public void setAgentName(String agentName) {
		this.agentName = agentName;
	}

	public Integer getSource() {
		return source;
	}

	public void setSource(Integer source) {
		this.source = source;
	}

	public Integer getReviewStatus() {
		return reviewStatus;
	}

	public void setReviewStatus(Integer reviewStatus) {
		this.reviewStatus = reviewStatus;
	}

	public Integer getFirstResult() {
		return firstResult;
	}

	public void setFirstResult(Integer firstResult) {
		this.firstResult = firstResult;
	}

	public Integer getSecondResult() {
		return secondResult;
	}

	public void setSecondResult(Integer secondResult) {
		this.secondResult = secondResult;
	}

	public String getFirstMemo() {
		return firstMemo;
	}

	public void setFirstMemo(String firstMemo) {
		this.firstMemo = firstMemo;
	}

	public String getSecondMemo() {
		return secondMemo;
	}

	public void setSecondMemo(String secondMemo) {
		this.secondMemo = secondMemo;
	}

	public Date getLastReviewTime() {
		return lastReviewTime;
	}

	public void setLastReviewTime(Date lastReviewTime) {
		this.lastReviewTime = lastReviewTime;
	}

	public String getFirstReviewer() {
		return firstReviewer;
	}

	public void setFirstReviewer(String firstReviewer) {
		this.firstReviewer = firstReviewer;
	}

	public String getAe() {
		return ae;
	}

	public void setAe(String ae) {
		this.ae = ae;
	}

	public String getSale() {
		return sale;
	}

	public void setSale(String sale) {
		this.sale = sale;
	}

	public String getSecondReviewer() {
		return secondReviewer;
	}

	public void setSecondReviewer(String secondReviewer) {
		this.secondReviewer = secondReviewer;
	}

	public List<RpsTagsDto> getLabels() {
		return labels;
	}

	public void setLabels(List<RpsTagsDto> labels) {
		this.labels = labels;
	}

	public Integer getAdvertType() {
		return advertType;
	}

	public void setAdvertType(Integer advertType) {
		this.advertType = advertType;
	}
}
